@@ -26,9 +26,8 @@ int main()
 {
   using namespace __gnu_test;
 
- // cplus-dem FAIL
-  verify_demangle("_Z3fooA30_A_i", "foo(int [30][])");
-
+  // cplus-dem FAIL
+  verify_demangle("_Z1fPFPA1_ivE", "f(int (*(*)()) [1])");
 
   return 0;
 }
